import { DataType } from './../../../core/entity/grid';
import { AddOrEditComponent } from './add-or-edit/add-or-edit.component';
import { Version } from '@angular/compiler/src/util';
import { Subject } from 'rxjs/Subject';
import { ToolsService } from '@core/services/tools.service';
import { Component, OnInit } from '@angular/core';
import { NzMessageService, NzModalService } from 'ng-zorro-antd';
import { ModalHelper } from '@delon/theme';
import { HttpClient } from '@angular/common/http';
import { environment } from '../../../../environments/environment';
import { DateService } from '@core/services/date.service';
import { VersionService } from 'app/routes/devices/version/version.service';
import { Types } from '@core/enum/types.enum';
import { Column, Grid, PageBean } from '@core/entity/grid';

export interface DeviceVersion {
  createTime?: Column|any;
  description?: Column|any;
  id?: Column|any;
  name?: Column|any;
  version?: Column|any;
}
@Component({
  selector: 'app-version',
  templateUrl: './version.component.html',
  styles: []
})
export class VersionComponent implements OnInit {
  private version: DeviceVersion;
  grid: Grid<DeviceVersion> = new Grid(null);
  queryMap = { text: '请输入名称或型号', value: ''};
  queryTextStream: Subject<string> = new Subject<string>();
    private initPage() {
    this.version = {
       name: {
        text: '名称',
        width: '18%'
       },
       version: {
        text: '型号',
        width: '18%'
      },
      createTime: {
          text: '创建时间',
          width: '18%',
          type: {
            name: Types.Date,
            format: 'YYYY-MM-DD HH:mm:ss'
          }
      },
      description: {
          text: '备注',
          width: '18%'
      }
    };
    this.grid.title = '设备型号';
    this.grid.setColumns(this.version);
    this.grid.pageSize = 10;
  }
  constructor(
    private versionService: VersionService,
    
    private confirmServ: NzModalService,
    public msgSrv: NzMessageService,
    private modalHelper: ModalHelper,
  ) {}

  ngOnInit() {
    this.initPage();
    this.queryTextStream
    .debounceTime(500)
    .distinctUntilChanged()
    .subscribe(queryText => {
        this.load();
    });
  }
  queryTextChanged($event) {
      this.queryTextStream.next(this.queryMap.value);
  }
  load(reload: boolean = false) {
    if (reload) {
      this.grid.pageIndex = 1 ;
    }
    this.versionService.getPagingList(this.grid, this.queryMap.value).subscribe(
       (res: PageBean) => {
            if (res != null && res.data != null) {
              this.grid.initData(res);
              this.grid.refreshStatus();
            }
       }
    );
  }

  edit() {
    // this.modalHelper.static(VersionEditComponent, { user }).subscribe(() => {
    //   this.load(true);
    //   this.msgSrv.success('安装用户修改成功！');
    // });
  }
// rowData为null时，为新增
  addOrModify(data) {
    if ( data == null) {
       data = {};
    }
    const cols = this.version;
    this.modalHelper.static(AddOrEditComponent, { cols , data }).subscribe( 
      ( ret: { data: any, close: Function} ) => {
      this.versionService.save(ret.data).subscribe(
         ( res: any) => {
            if (res.code === 1) {
              this.load(true);
              ret.close();
              this.msgSrv.success('设备型号保存成功！');
            }
         }
      );
    });
  }

  delete(...id: number[]) {
    this.versionService.delete( ...id ).subscribe(
      ( res: any) => {
         if (res.code === 1) {
           this.load(true);
           this.msgSrv.success('设备型号删除成功！');
         }
      }
   );
  }

   deleteSelected() {
    this.confirmServ.confirm({
      title: '批量删除',
      content: '注意：数据一旦删除，将不可恢复！',
      okText: '确定',
      cancelText: '取消'
    }).on('onOk', () => {
       if (this.grid.selectedIndexs != null && this.grid.selectedIndexs.length > 0) {
          const ids = this.grid.selectedIndexs.map(
              (index: number) => {
                  return Number.parseInt(this.grid.data[index].id);
              }
          );
          this.delete( ...ids );
       }
    });
  }


  dataChange(res: any) {

  }

  sort(field: string, value: any) {
    // this.sortMap = {};
    // this.sortMap[field] = value;
    // this.q.sorter = value ? `${field}_${value}` : '';
    // this.load(true);
  }

  reset(ls: any[]) {
    for (const item of ls) item.value = false;
    this.load(true);
  }

}
